default_context:
    project_name: "{{ settings.package }} Sample site"
    project_shortname: "{{ settings.package }}-sample-site"
    project_site: "oarepo.org"
    github_repo: "oarepo/{{ settings.package }}-sample-site"
    description: "Testing OARepo Site instance for {{ settings.package}} datamodel."
    author_name: "CESNET"
    author_email: "info@oarepo.org"
    year: "2022"
    python_version: "3.9"
    database: "postgresql"
    elasticsearch: "7"
    file_storage: "S3"
    development_tools: "yes"
    app_package: "{{ settings.package }}"
